commit 0b3eb56d67b27745778ac93949a154468bba2e64
Author: Pavel Fidranský <fidransky@outlook.com>
Date:   Sat Oct 20 21:44:39 2018 +0200

    renamed InvalidArgumentException class to InvalidExceptionError to comply with JS conventions

diff --git a/sources/src/main/webapp/js/errors/invalidArgumentError.js b/sources/src/main/webapp/js/errors/invalidArgumentError.js
new file mode 100644
index 0000000..bf66d2a
--- /dev/null
+++ b/sources/src/main/webapp/js/errors/invalidArgumentError.js
@@ -0,0 +1,5 @@
+/**
+ * Error thrown when an argument of the function call is not valid.
+ */
+class InvalidArgumentError extends Error {
+}
diff --git a/sources/src/main/webapp/js/exceptions/invalidArgumentException.js b/sources/src/main/webapp/js/exceptions/invalidArgumentException.js
deleted file mode 100644
index 03a4278..0000000
--- a/sources/src/main/webapp/js/exceptions/invalidArgumentException.js
+++ /dev/null
@@ -1,9 +0,0 @@
-/**
- * Exception thrown when an argument of the function call is not valid.
- * @constructor
- * @param {string} message Message of the exception.
- */
-function InvalidArgumentException(message) {
-	/** @prop {string} message */
-	this.message = message;
-}
diff --git a/sources/src/main/webapp/showGraph.jsp b/sources/src/main/webapp/showGraph.jsp
index 04c11bc..51b50e1 100644
--- a/sources/src/main/webapp/showGraph.jsp
+++ b/sources/src/main/webapp/showGraph.jsp
@@ -39,7 +39,7 @@
 		<script src="js/components/vertexSymbolList.js"></script>
 		<script src="js/components/viewport.js"></script>
 
-		<script src="js/exceptions/invalidArgumentException.js"></script>
+		<script src="js/errors/invalidArgumentError.js"></script>
 
 		<script src="js/constants.js"></script>
 		<script src="js/coordinates.js"></script>

diff --git a/sources/src/main/webapp/js/graphLoader.js b/sources/src/main/webapp/js/graphLoader.js
index 2695483..c9041f0 100644
--- a/sources/src/main/webapp/js/graphLoader.js
+++ b/sources/src/main/webapp/js/graphLoader.js
@@ -6,11 +6,11 @@ function GraphLoader() {
 	/**
 	 * Loads a new graph using graph data passed as parameters.
 	 * @param {object} data Data of the graph.
 	 * @throws {InvalidArgumentException} Thrown when either graph data are incomplete.
 	 */
 	this.run  = function(data) {
 		if (app.utils.isUndefined(data.vertices) || app.utils.isUndefined(data.edges)) {
-			throw new InvalidArgumentException('Invalid data.');
+			throw new InvalidArgumentError('Invalid data.');
 		}
 
 		var canvasSize = ((data.vertices.length * 75) / Math.round(Math.sqrt(data.vertices.length))) + 1000;
@@ -6,11 +6,11 @@ function GraphLoader() {
 	 * Loads a new graph using graph data passed as parameters.
 	 * @param {object} data Data of the graph.
-	 * @throws {InvalidArgumentException} Thrown when either graph data are incomplete.
+	 * @throws {InvalidArgumentError} Thrown when either graph data are incomplete.
 	 */
 	this.run  = function(data) {
diff --git a/sources/src/main/webapp/js/utils/dom.js b/sources/src/main/webapp/js/utils/dom.js
index d0cbf95..ad715eb 100644
--- a/sources/src/main/webapp/js/utils/dom.js
+++ b/sources/src/main/webapp/js/utils/dom.js
@@ -26,11 +26,11 @@ function DOM() {
 	 * @param {string} tagName Type of the newly created element (div, span, ...).
 	 * @param {object} attributes Attributes of the element.
 	 * @returns {Element} HTML DOM element.
 	 * @throws {InvalidArgumentException} Thrown when tagName is not a valid HTML tag.
 	 */
 	this.createHtmlElement = function(tagName, attributes) {
 		if (htmlTags.indexOf(tagName) === -1) {
-			throw new InvalidArgumentException(tagName, 'is not a valid HTML element');
+			throw new InvalidArgumentError(tagName + 'is not a valid HTML element');
 		}
 
 		var element = document.createElement(tagName);
@@ -47,11 +47,11 @@ function DOM() {
 	 * @param {string} tagName Type of the element (circle, rect, ...).
 	 * @param {object} attributes Attributes of the element.
 	 * @returns {Element} SVG DOM element.
 	 * @throws {InvalidArgumentException} Thrown when tagName is not a valid SVG tag.
 	 */
 	this.createSvgElement = function(tagName, attributes) {
 		if (svgTags.indexOf(tagName) === -1) {
-			throw new InvalidArgumentException(tagName, 'is not a valid SVG element');
+			throw new InvalidArgumentError(tagName + 'is not a valid SVG element');
 		}
 
 		var element = document.createElementNS('http://www.w3.org/2000/svg', tagName);
@@ -26,11 +26,11 @@ function DOM() {
 	 * @param {object} attributes Attributes of the element.
 	 * @returns {Element} HTML DOM element.
-	 * @throws {InvalidArgumentException} Thrown when tagName is not a valid HTML tag.
+	 * @throws {InvalidArgumentError} Thrown when tagName is not a valid HTML tag.
 	 */
 	this.createHtmlElement = function(tagName, attributes) {
@@ -47,11 +47,11 @@ function DOM() {
 	 * @param {object} attributes Attributes of the element.
 	 * @returns {Element} SVG DOM element.
-	 * @throws {InvalidArgumentException} Thrown when tagName is not a valid SVG tag.
+	 * @throws {InvalidArgumentError} Thrown when tagName is not a valid SVG tag.
 	 */
 	this.createSvgElement = function(tagName, attributes) {